@@ -29,7 +29,7 @@ This file implement commons functions and class for WebScripts package."""
 from typing import TypeVar, Tuple, List, Dict
 from configparser import ConfigParser
 from collections.abc import Callable
-from subprocess import Popen, PIPE
+from subprocess import Popen, PIPE  # nosec
 from types import SimpleNamespace
 from base64 import b64encode
 from os import path, getcwd
@@ -40,7 +40,7 @@ from time import time
 import secrets
 import json
 
-__version__ = "0.0.8"
+__version__ = "0.0.9"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -402,8 +402,11 @@ class ScriptConfig(DefaultNamespace):
             return
 
         process = Popen(
-            ["cmd", "/c", "assoc", extension], stdout=PIPE, stderr=PIPE, text=True
-        )
+            [r"C:\WINDOWS\system32\cmd.exe", "/c", "assoc", extension],
+            stdout=PIPE,
+            stderr=PIPE,
+            text=True,
+        )  # nosec
         stdout, stderr = process.communicate()
 
         if process.returncode != 0:
@@ -411,8 +414,11 @@ class ScriptConfig(DefaultNamespace):
         filetype = stdout.split("=")[1] if "=" in stdout else ""
 
         process = Popen(
-            ["cmd", "/c", "ftype", filetype], stdout=PIPE, stderr=PIPE, text=True
-        )
+            [r"C:\WINDOWS\system32\cmd", "/c", "ftype", filetype],
+            stdout=PIPE,
+            stderr=PIPE,
+            text=True,
+        )  # nosec
         stdout, stderr = process.communicate()
 
         if process.returncode != 0:
